import { RefObject } from "react";
import { CalculateFixedPositionOptions, LabelRequiredForA11y } from "@react-md/utils";
import { BaseDialogProps } from "./Dialog";
export interface BaseFixedDialogProps extends Omit<BaseDialogProps, "type">, Pick<CalculateFixedPositionOptions, "anchor"> {
    /**
     * The element the dialog should be fixed to. This can either be:
     * - a query selector string to get an element
     * - an HTMLElement (normally a ref.current)
     * - a function that returns an HTMLElement or null
     * - null
     */
    fixedTo: RefObject<HTMLElement>;
    /**
     * Any additional options to apply to the fixed positioning logic. The
     * `transformOrigin` option will be enabled by default.
     */
    options?: CalculateFixedPositionOptions;
    /**
     * An optional function to call to get the fixed positioning options.
     */
    getOptions?(): CalculateFixedPositionOptions;
}
export declare type FixedDialogProps = LabelRequiredForA11y<BaseFixedDialogProps>;
/**
 * The `FixedDialog` is a wrapper for the `Dialog` component that can be used to
 * be fix itself to another element. Another term for this component might be a
 * "Pop out Dialog".
 */
export declare const FixedDialog: import("react").ForwardRefExoticComponent<FixedDialogProps & import("react").RefAttributes<HTMLDivElement>>;
